@@ -6,10 +6,9 @@
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-client.h>
 #include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-window-icon.h>
+#include <libgnomeui/gnome-authentication-manager.h>
 #include <gconf/gconf-client.h>
 #include "util.h"
-#include "eog-hig-dialog.h"
 #include "eog-window.h"
 #include "eog-thumbnail.h"
 #include "session.h"
@@ -161,15 +160,20 @@ create_new_window (void)
 
 	if (error != NULL) {
 		GtkWidget *dlg;
-		dlg = eog_hig_dialog_new (NULL, GTK_STOCK_DIALOG_ERROR,
-					  _("Unable to create Eye of GNOME user interface"), error->message, TRUE);
-		gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK, GTK_RESPONSE_OK);
 
-		g_error_free (error);
+		dlg = gtk_message_dialog_new (NULL,
+					      GTK_DIALOG_MODAL,
+					      GTK_MESSAGE_ERROR,
+					      GTK_BUTTONS_OK,
+					      _("Unable to create Eye of GNOME user interface"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+							  error->message);
 
 		gtk_dialog_run (GTK_DIALOG (dlg));
 		gtk_widget_destroy (GTK_WIDGET (dlg));
 
+		g_error_free (error);
+
 		gtk_main_quit ();
 	}
 	else {
@@ -338,19 +342,20 @@ static gint
 user_wants_collection (gint n_windows)
 {
 	GtkWidget *dlg;
-	gchar body[128];
 	int ret;
 
-	g_snprintf (body, 128,
-		    ngettext ("You are about to open %i windows simultaneously. Do you want to open them in a collection instead?",
-	                  "You are about to open %i windows simultaneously. Do you want to open them in a collection instead?",
-	                  n_windows),
-		              n_windows);
-
-	dlg = eog_hig_dialog_new (NULL, GTK_STOCK_DIALOG_WARNING,
-				  _("Open multiple single windows?"),
-				  body,
-				  TRUE);
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_WARNING,
+				      GTK_BUTTONS_NONE,
+				      _("Open multiple single windows?"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+				      ngettext ("You are about to open %i windows simultaneously."
+						" Do you want to open them in a collection instead?",
+						"You are about to open %i windows simultaneously."
+						" Do you want to open them in a collection instead?",
+						n_windows),
+				      n_windows);
 
 	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Single Windows"), COLLECTION_NO);
 	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_CANCEL, COLLECTION_CANCEL);
@@ -404,13 +409,14 @@ show_nonexistent_files (GList *error_list)
 		g_free (str);
 		n++;
 	}
-	
-	dlg = eog_hig_dialog_new (NULL, GTK_STOCK_DIALOG_ERROR, 
-				  ngettext ("File not found.", "Files not found.", len),
-				  detail->str, TRUE);
-	gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK, GTK_RESPONSE_OK);
-	
-	gtk_widget_show (dlg);
+
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_ERROR,
+				      GTK_BUTTONS_OK,
+				      ngettext ("File not found.", "Files not found.", len));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg), detail->str);
+
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
 
@@ -664,7 +670,6 @@ int
 main (int argc, char **argv)
 {
 	GnomeProgram *program;
-	GError *error;
 	poptContext ctx;
 	GnomeClient *client;
 	char *gnome_eog_png_path;
@@ -678,18 +683,11 @@ main (int argc, char **argv)
 				      GNOME_PARAM_HUMAN_READABLE_NAME, _("Eye of GNOME"),
 				      GNOME_PARAM_APP_DATADIR,EOG_DATADIR,NULL);
 
-	error = NULL;
-	if (gconf_init (argc, argv, &error) == FALSE) {
-		g_assert (error != NULL);
-		g_message ("GConf init failed: %s", error->message);
-		g_error_free (error);
-		exit (EXIT_FAILURE);
-	}
-
-	if(gnome_vfs_init () == FALSE) {
+	if (gnome_vfs_init () == FALSE) {
 		g_error ("Could not initialize GnomeVFS!");
 		exit (EXIT_FAILURE);
 	}
+
 #ifndef G_OS_WIN32
 	gnome_authentication_manager_init ();
 #endif
